from matplotlib import pyplot as plt
import subprocess
import re
import os

params = {
    '--lr': ['0.1', '1', '100'],
    '--epochs': ['20', '50', '100'],
    '--batch_size': ['4', '16', '64'],
    '--sequence_length': ['8', '32', '128'],
    '--dimension_model': ['64', '256', '512'],
    '--nhead': ['2', '4', '8'],
    '--dropout': ['0.0', '0.3', '0.6'],
    '--nhid': ['50', '100', '500'],
    '--nlayers': ['2', '6', '10'],
}

if __name__ == '__main__':
    venv_path = 'venv'

    # Path to the virtual environment's bin or Scripts directory
    if os.name == 'nt':  # For Windows
        venv_python = os.path.join(venv_path, 'Scripts', 'python')
    else:  # For Unix or MacOS
        venv_python = os.path.join(venv_path, 'bin', 'python')

    i = 0
    for param, param_vals in params.items():
        losses = []
        for param_val in param_vals:
            res = subprocess.run([venv_python, 'main.py', param, param_val],
                                 stdout=subprocess.PIPE,
                                 stderr=subprocess.PIPE
                                 )
            res_stdout = res.stdout.decode()
            res_stderr = res.stderr.decode()
            match = re.search(r'test loss\s+([0-9.]+)', res_stdout)
            if match:
                test_loss = float(match.group(1))
                losses.append(test_loss)
                print(param, param_val, test_loss)
            else:
                print("ERROR:", res_stdout, res_stderr)

        plt.figure(i)
        plt.title(f"Influence du paramètre {param}")
        plt.plot(param_vals, losses)
        plt.xlabel(param)
        plt.ylabel("loss")
        plt.savefig(f"{param}.png")
        i += 1

    plt.show()
